@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from typing import Dict, List, Union, Optional
+from typing import Dict, List, Optional, Union
 
 import cloudpickle
 import mlflow
